@@ -23,7 +23,7 @@ Player::~Player()
 
 void Player::openArticle(QString itemName, QString text)
 {
-    path = itemName.toLower().normalized(QString::NormalizationForm_D)+".txt";
+    path = QDesktopServices::storageLocation(QDesktopServices::DocumentsLocation) + itemName.toLower().normalized(QString::NormalizationForm_D)+".txt";
 
     QStringList links;
     QFile *articleLinks = new QFile(QDesktopServices::storageLocation(QDesktopServices::DocumentsLocation) +  itemName.toLower().normalized(QString::NormalizationForm_D)+".dat");
